@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef gama_local_GKF__XML__parser__h_
-#define gama_local_GKF__XML__parser__h_
+#ifndef gama_local_GKF_XML_parser_h_
+#define gama_local_GKF_XML_parser_h_
 
 #include <gnu_gama/xml/baseparser.h>
 #include <gnu_gama/xml/dataobject.h>
